#!/usr/bin/perl

# Usage:
#   perl runtest.pl [outputfile]
#
# If omitted, output file will default to perftestWin32.html or perftestLinux.html

# Globals
$windows = $^O =~ "MSWin32";

$JENA_1_ROOT = $ENV{"JENA1_ROOT"} ? $ENV{"JENA1_ROOT"} : "../jena";
$JENA_2_ROOT = $ENV{"JENA2_ROOT"} ? $ENV{"JENA2_ROOT"} : "../jena2";

$JAVA_1_3_ROOT = $ENV{"JDK_13_HOME"} ? $ENV{"JDK_13_HOME"} : ($windows ? "c:/java/jdk1.3" : "/usr/local/jdk1.3.1");
$JAVA_1_4_ROOT = $ENV{"JDK_13_HOME"} ? $ENV{"JDK_13_HOME"} : ($windows ? "C:/Java/j2sdk1.4.1_01" : "/usr/local/jdk1.4.1");
$JAVA_1_3 = "${JAVA_1_3_ROOT}/bin/java";
$JAVA_1_4 = "${JAVA_1_4_ROOT}/bin/java";

@sizes = (qw(10 100 1000 10000 100000));
#@sizes = (qw(10 100 1000)); # for testing only

@sizesSlow = (qw(10 100 1000));
#@sizesSlow = (qw(10 100 )); # for testing only

# the test programs to run
@tests = (qw(ARPPerfTest ModelCreatePerfTest WalkTest RDQLPerfTest ));
@slowTests = (qw(DERPerfTest WritePerfTest ));

$j1Time = 0;
$j1WSum = 0;
$j2WSum = 0;
$j1Sum = 0;
$j2Sum = 0;

$target = defined($ARGV[0]) ? $ARGV[0] : ($windows ? "perftestWin32.html" : "perftestLinux.html");

# Main program
open HOUT, "> $target";

docStart();

# run the quick tests
foreach $test (@tests) {
    runNamedTest( $test, @sizes );
}

# run the slow tests
foreach $test (@slowTests) {
    runNamedTest( $test, @sizesSlow );
}


docEnd();
close HOUT;



sub runNamedTest {
    my( $testName, $s, $newTest, @sz );
    ($testName, @sz) = @_;
    $newTest  = 1;

    foreach $s (@sz) {
        runNamedJena1Test( $testName, $s, $newTest, $JAVA_1_3 );

        $newTest = 0;

        runNamedJena2Test( $testName, $s, $newTest, $JAVA_1_3 );
    }

    mean();
    $newTest = 1;

    foreach $s (@sz) {
        runNamedJena1Test( $testName, $s, $newTest, $JAVA_1_4 );

        $newTest = 0;

        runNamedJena2Test( $testName, $s, $newTest, $JAVA_1_4 );
    }

    mean();
}

sub runNamedJena1Test {
    my( $testName, $s, $newTest, $jdk, $cmd );
    ($testName, $s, $newTest, $jdk) = @_;

    my $classpath = getLibs( $JENA_1_ROOT );

    $cmd = "$jdk -Xmx128M -cp $classpath -Djena.perftest.size=$s com.hp.hpl.jena.test.performance.${testName}_Jena1";
    #print "Running $cmd ...\n";
    print "${testName}_Jena1 $s $jdk\n";

    my $return = `$cmd`;

    datapoint( $return, $newTest, 1 );
}

sub runNamedJena2Test {
    my( $testName, $s, $newTest, $jdk, $cmd );
    ($testName, $s, $newTest, $jdk) = @_;

    my $classpath = getLibs( $JENA_2_ROOT );

    $cmd = "$jdk -Xmx128M -cp $classpath -Djena.perftest.size=$s com.hp.hpl.jena.test.performance.${testName}_Jena2";
    #print "Running $cmd ...\n";
    print "${testName}_Jena2 $s $jdk\n";

    my $return = `$cmd`;

    datapoint( $return, $newTest, 0 );
}

sub getLibs {
    my( $root, $pathsep );
    ($root) = @_;
    my @libs = glob "${root}/lib/*.jar";
    $pathSep = $windows ? ";" : ":";

    my $cp = "./classes";
    foreach $lib (@libs) {
        $cp = $cp . $pathSep . "$lib";
    }

    $cp;
}

sub docStart {
     $now = gmtime;
     print HOUT "<html>\n";
     print HOUT "<head>\n";
     print HOUT "  <title>Jena 1 vs Jena 2 Performance test results</title>\n";
     print HOUT "</head>\n";
     print HOUT "<body>\n";
     print HOUT "  <h2>Jena 1 vs Jena 2 performance comparison results</h2>\n";
     print HOUT "  <p>The test was begun at $now</p>\n";
     print HOUT "  <table border='1' width='600' rules='rows'>\n";
     print HOUT "    <tr align='right'><th>Size</th><th>Jena 1</th><th>Jena 2</th><th>Speed-up<br>(Slow-down)</th></tr>\n";
}

sub docEnd {
     $now = gmtime;
     print HOUT "  </table>\n";
     print HOUT "  <p>The test ended at $now</p>\n";
     print HOUT "</body>\n";
     print HOUT "</html>\n";
}

sub datapoint {
    my( $result, $newTest, $jena1, $vm, $desc, $size, $tim );
    ($result, $newTest, $jena1) = @_;

    $result =~ "Jena2-PerfTest,(.*),(.*),(.*),(.*)";
    ($vm, $desc, $size, $tim) = ($1, $2, $3, $4);

    if ($size == 0) {
        print "Warning: size should not be zero - defaulting to 10\n";
        $size = 10;
    }

    $tim = ($tim > 0) ? $tim : 0.01;

    if ($newTest) {
        print HOUT "<tr bgcolor='#DDDDDD'><td colspan='4'>$vm<br />$desc</td></tr>\n";
    }

    if ($jena1) {
        printf HOUT "<tr align='right'><td>$size</td><td>%.2f ms</td>", $tim;
        $j1Time = $tim;
        $j1WSum += ($tim / $size);
        $j1Sum += $tim;
    }
    else {
        my( $ratio ) = ratio( $j1Time, $tim );
        $j2WSum += ($tim / $size);
        $j2Sum += $tim;

        printf HOUT "<td>%.2f ms</td><td>%s</td></tr>\n", $tim, renderNegative( $ratio );
    }
}

sub mean {
    my( $mean ) = ratio( $j1Sum, $j2Sum );
    my( $wmean ) = ratio( $j1WSum, $j2WSum );
    printf HOUT "<tr align='right'><td colspan='3'>Average:<br>Weighted average:</td><td>%s<br>%s</td></tr>\n", renderNegative( $mean ), renderNegative( $wmean );
    $j1Sum = 0;
    $j2Sum = 0;
    $j1WSum = 0;
    $j2WSum = 0;
}

sub ratio {
    my($j1, $j2) = @_;


    ($j1 < $j2) ? (-1.0 * $j2 / $j1 ) : ($j1 / $j2);
}

sub renderNegative {
    my( $x ) = @_;
    ($x < 0) ? sprintf( "(%.1f)", -1.0 * $x ) : sprintf( "%.1f", $x );
}