/*****************************************************************************
 * Source code information
 * -----------------------
 * Original author    Ian Dickinson, HP Labs Bristol
 * Author email       Ian_Dickinson@hp.com
 * Package            Jena performanace tests
 * Created            11 June 2002
 * Filename           $RCSfile: ARPPerfTest_Jena1.java,v $
 * Revision           $Revision: 1.4 $
 * Release status     Experimental. Do not distribute. $State: Exp $
 *
 * Last modified on   $Date: 2003/05/02 08:40:24 $
 *               by   $Author: jeremy_carroll $
 *
 * @copyright@
 *****************************************************************************/

// Package
///////////////
package com.hp.hpl.jena.test.performance;

// Imports
///////////////

import com.hp.hpl.jena.rdf.arp.*;
import java.io.*;
import org.xml.sax.*;

/**
 * <p>
 * A simple test of raw ARP parsing and reading performance (Jena 1.X version)
 * </p>
 *
 * @author Ian Dickinson, HP Labs (<a href="mailto:Ian.Dickinson@hp.com">email</a>)
 * @version CVS info: $Id: ARPPerfTest_Jena1.java,v 1.4 2003/05/02 08:40:24 jeremy_carroll Exp $
 */
public class ARPPerfTest_Jena1 extends AbstractARPPerfTest {
	// Constants
	//////////////////////////////////

	// Static variables
	//////////////////////////////////

	static int triples = 0;
	static int errs = 0;
	static int warns = 0;
	static int fatals = 0;

	// Instance variables
	//////////////////////////////////

	// Constructors
	//////////////////////////////////

	// External signature methods
	//////////////////////////////////

	public void runTest(int size) throws Exception {
		String fileName = "rdf/" + size + "dmoz.rdf";
		ARP a = new ARP();

		StatementHandler sh = new StatementHandler() {
			public void statement(
				AResource subj,
				AResource pred,
				ALiteral obj) {
				triples++;
			}
			public void statement(
				AResource subj,
				AResource pred,
				AResource obj) {
				triples++;
			}
		};

		a.setStatementHandler(sh);

		ErrorHandler eh = new ErrorHandler() {
			public void warning(SAXParseException e) {
				warns++;
			}
			public void error(SAXParseException e) {
				errs++;
			}
			public void fatalError(SAXParseException e) {
				fatals++;
			}
		};
		a.setErrorHandler(eh);

		// open and parse the file
		InputStream in = new ByteArrayInputStream(data);
		a.load(in, url);

		in.close();

	}

	public String getDescription() {
		return "Simple ARP throughput - read 'size' lines of DMOZ input";
	}

	public static void main(String[] args) {
		ARPPerfTest_Jena1 t = new ARPPerfTest_Jena1();
		t.go(args);
		System.err.println(
			"Triples: "
				+ triples
				+ " Bytes: "
				+ t.data.length
				+ " Warnings: "
				+ warns
				+ " Errors: "
				+ errs
				+ "/"
				+ fatals);

	}

	// Internal implementation methods
	//////////////////////////////////

	//==============================================================================
	// Inner class definitions
	//==============================================================================

}

/* 
@footer@ 
*/
