/* -*-Java-*-
*******************************************************************
* File:         PerformanceTest.java
* RCS:          $Header: /cvsroot/jena//jena-perf/src/com/hp/hpl/jena/test/performance/DERPerfTest_Jena1.java,v 1.1 2003/01/23 16:25:18 ian_dickinson Exp $
* Author:       Dave Reynolds, HPLabs, Bristol
* Created:      5/12/02
* Modified:     $Date: 2003/01/23 16:25:18 $
* Package:      eperson
* Status:       Experimental (Do Not Distribute)
*
* (c) Copyright 2002, Hewlett-Packard Company, all rights reserved.
*********************************************************************/

//=======================================================================
// Package
package com.hp.hpl.jena.test.performance;

//=======================================================================
// Imports

import com.hp.hpl.mesa.rdf.jena.model.*;
import com.hp.hpl.mesa.rdf.jena.mem.ModelMem;


//=======================================================================
/**
* Trivial performance tester to estimate jena2 overheads by der.  Moved to performance
* test suite by ijd.
*
* @author <a href="mailto:der@hplb.hpl.hp.com">Dave Reynolds</a>
* @author <a href="mailto:Ian.Dickinson@hp.com">Ian Dickinson</a>
* @version $Revision: 1.1 $ on $Date: 2003/01/23 16:25:18 $
*/

public class DERPerfTest_Jena1
    extends AbstractPerfTest
{

//=======================================================================
// Variables

    /** dummy namespace */
    public static final String NAMESPACE = "urn:x-hp-test:foo/";

    /** number of predicates in the test model */
    public static final int N_PREDICATES = 10;
    
    /** The model to traverse */
    protected Model m_model = null;
    

//=======================================================================
// Constructors


//=======================================================================
// Methods


    /**
     * Create a test model
     * @param nsubjects the number of subject resources
     * @param npredicates the number of predicates to be attached to ech subject
     * @param unique if true every object will be distinct, if false there will only be npredicate objects
     * @return the synthesised model
     */
    public Model createTest(int nsubjects, int npredicates, boolean unique)  throws RDFException {
        Model model = new ModelMem();

        // Create  the properties
        Property[] props = new Property[npredicates];
        for (int i = 0; i < npredicates; i++) {
            props[i] = model.createProperty(NAMESPACE, "p" + i);
        }

        // Create the statements
        for (int s = 0; s < nsubjects; s++) {
            Resource subj = model.createResource(NAMESPACE + "r" + s);
            for (int p = 0; p < npredicates; p++) {
                Resource obj = model.createResource(NAMESPACE + (unique ? "r" + s + "o" : "o") + p);
                model.add(subj, props[p], obj);
            }
        }

        return model;
    }

    /**
     * Abstract method that runs the actual test.
     * 
     * @param size Context dependent size parameter, such as the number of statements to create
     */
    public void runTest( int size ) 
        throws Exception
    {
        for (int i = 0; i < size; i++) {
            long count = 0;
            StmtIterator s = m_model.listStatements();
            while (s.hasNext()) {
                s.next();
                count++;
            }
        }
    }
    

    /**
     * Answer the human readable description of the test, that will appear on the generated html
     * @return The description of the test
     */
    public String getDescription() {
        return "Dave's performance test - listStatements() in a model with 'size' statements";
    }
    

    /**
     * Do any necessary setup for the main test. Default is to do nothing.
     * 
     * @param size The (context dependent) size parameter for this test
     */
    protected void setupTest( int size ) 
        throws Exception
    {
        int nSubjects = Math.round( size / N_PREDICATES );
        m_model = createTest( (nSubjects == 0) ? 1 : nSubjects, N_PREDICATES, true);
    }

    /**
     * Entry point
     */
    public static void main( String[] args ) {
        new DERPerfTest_Jena1().go( args );
    }


} //end of class


