/********************************************************************
 * File:         PerformanceTest.java
 * RCS:          $Header: /cvsroot/jena/jena-perf/src/com/hp/hpl/jena/test/performance/ModelCreatePerfTest_Jena2.java,v 1.1 2003/01/23 16:25:18 ian_dickinson Exp $
 * Author:       Dave Reynolds, HPLabs, Bristol
 * Created:      5/12/02
 * Modified:     $Date: 2003/01/23 16:25:18 $
 * Package:      eperson
 * Status:       Experimental (Do Not Distribute)
 *
 * (c) Copyright 2002, Hewlett-Packard Company, all rights reserved.
 *********************************************************************/

// Package
package com.hp.hpl.jena.test.performance;

// Imports

import com.hp.hpl.jena.rdf.model.*;
import com.hp.hpl.jena.mem.*;
import com.hp.hpl.jena.vocabulary.*;

import java.io.*;


/**
* Performance test: create a model containing synthesised statements
*
* @author <a href="mailto:Ian.Dickinson@hp.com">Ian Dickinson</a>
* @version $Revision: 1.1 $ on $Date: 2003/01/23 16:25:18 $
*/

public class ModelCreatePerfTest_Jena2
    extends AbstractPerfTest
{

    // Variables

    /** dummy namespace */
    public static final String NAMESPACE = "urn:x-hp-test:performance/";

    /** some arbitrary class */
    public static final String A_CLASS = "urn:x-hp-test:performance/A";

    /**
     * Setup
     * @param size the number of statements to write out
     */
    public void setupTest( int size )
        throws Exception
    {
    }

    /**
     * Abstract method that runs the actual test.
     *
     * @param size Context dependent size parameter, such as the number of statements to create
     */
    public void runTest( int size )
        throws Exception
    {
        Model model = new ModelMem();

        // Create  the properties
        Property p = model.createProperty( NAMESPACE, "p" );
        Resource cls = model.createResource( A_CLASS );

        // Create the statements
        for ( int i = 0;  i < size;  i++) {
            Resource r = model.createResource();
            r.addProperty( p, i );
            r.addProperty( RDF.type, cls );
        }
    }


    /**
     * Answer the human readable description of the test, that will appear on the generated html
     * @return The description of the test
     */
    public String getDescription() {
        return "Create a model and add 'size' subjects - each with two properties";
    }


    /**
     * Entry point
     */
    public static void main( String[] args ) {
        new ModelCreatePerfTest_Jena2().go( args );
    }


} //end of class


