/********************************************************************
 * File:         PerformanceTest.java
 * RCS:          $Header: /cvsroot/jena/jena-perf/src/com/hp/hpl/jena/test/performance/RDQLPerfTest_Jena2.java,v 1.1 2003/01/23 16:25:19 ian_dickinson Exp $
 * Author:       Dave Reynolds, HPLabs, Bristol
 * Created:      5/12/02
 * Modified:     $Date: 2003/01/23 16:25:19 $
 * Package:      eperson
 * Status:       Experimental (Do Not Distribute)
 *
 * (c) Copyright 2002, Hewlett-Packard Company, all rights reserved.
 *********************************************************************/

// Package
package com.hp.hpl.jena.test.performance;

// Imports

import com.hp.hpl.jena.rdf.model.*;
import com.hp.hpl.jena.mem.*;
import com.hp.hpl.jena.vocabulary.*;
import com.hp.hpl.jena.rdql.*;

import java.io.*;
import java.util.*;

/**
* Performance test: very simple rdql query
*
* @author <a href="mailto:Ian.Dickinson@hp.com">Ian Dickinson</a>
* @version $Revision: 1.1 $ on $Date: 2003/01/23 16:25:19 $
*/

public class RDQLPerfTest_Jena2
    extends AbstractPerfTest
{

    // Variables

    /** dummy namespace */
    public static final String NAMESPACE = "urn:x-hp-test:performance/";
    
    /** some arbitrary class */
    public static final String A_CLASS = "urn:x-hp-test:performance/A";

    /** The model to traverse */
    protected Model m_model = null;
    
    /**
     * Create a test model
     * @param size the number of statements to write out
     */
    public void setupTest( int size )  
        throws Exception 
    {
        m_model = new ModelMem();

        // Create  the properties
        Property p = m_model.createProperty( NAMESPACE, "p" );
        Resource cls = m_model.createResource( A_CLASS );
        
        // Create the statements
        for ( int i = 0;  i < size;  i++) {
            Resource r = m_model.createResource();
            r.addProperty( p, i );
            r.addProperty( RDF.type, cls );
        }
    }

    /**
     * Abstract method that runs the actual test.
     * 
     * @param size Context dependent size parameter, such as the number of statements to create
     */
    public void runTest( int size ) 
        throws Exception
    {
        Query query = new Query( "SELECT ?x WHERE (?x, <http://www.w3.org/1999/02/22-rdf-syntax-ns#type>, <urn:x-hp-test:performance/A>)" );
        
        // Need to set the source if the query does not.
        // This provided this override any query named source.
        query.setSource( m_model );
        QueryExecution qe = new QueryEngine(query) ;
        QueryResults results = qe.exec() ;
        for ( Iterator iter = results ; iter.hasNext() ; )
        {
            ResultBinding res = (ResultBinding)iter.next() ;
            // Return from get is null if not found
            Object obj = res.get("x") ;
            // obj will be a Jena object: resource, property or RDFNode.
        }
        results.close() ;
    }
    

    /**
     * Answer the human readable description of the test, that will appear on the generated html
     * @return The description of the test
     */
    public String getDescription() {
        return "Use RDQL to query for 'size' resources with a given rdf:type";
    }
    

    /**
     * Entry point
     */
    public static void main( String[] args ) {
        new RDQLPerfTest_Jena2().go( args );
    }


} //end of class


