/********************************************************************
 * File:         PerformanceTest.java
 * RCS:          $Header: /cvsroot/jena//jena-perf/src/com/hp/hpl/jena/test/performance/WalkTest_Jena1.java,v 1.1 2003/01/23 16:25:19 ian_dickinson Exp $
 * Author:       Dave Reynolds, HPLabs, Bristol
 * Created:      5/12/02
 * Modified:     $Date: 2003/01/23 16:25:19 $
 * Package:      eperson
 * Status:       Experimental (Do Not Distribute)
 *
 * (c) Copyright 2002, Hewlett-Packard Company, all rights reserved.
 *********************************************************************/

// Package
package com.hp.hpl.jena.test.performance;

// Imports

import com.hp.hpl.mesa.rdf.jena.model.*;
import com.hp.hpl.mesa.rdf.jena.mem.*;
import com.hp.hpl.mesa.rdf.jena.vocabulary.*;

/**
* Performance test: walk a graph of connected statements from end to end
*
* @author <a href="mailto:Ian.Dickinson@hp.com">Ian Dickinson</a>
* @version $Revision: 1.1 $ on $Date: 2003/01/23 16:25:19 $
*/

public class WalkTest_Jena1
    extends AbstractPerfTest
{

    // Variables

    /** dummy namespace */
    public static final String NAMESPACE = "urn:x-hp-test:performance/";
    
    /** the start of the chain */
    public static final String START = "urn:x-hp-test:performance/start";

    /** The model to traverse */
    protected Model m_model = null;
    
    /** The linking property */
    protected Property m_p;

    /**
     * Create a test model
     * @param size the number of statements to link together
     */
    public void setupTest( int size )  
        throws Exception 
    {
        m_model = new ModelMem();

        // Create  the properties
        m_p = m_model.createProperty( NAMESPACE, "p" );
        Resource chain = m_model.createResource( START );
        
        // Create the statements
        for ( int i = 0;  i < size;  i++) {
            Resource link = m_model.createResource();
            chain.addProperty( m_p, link );
            chain = link;
        }
    }

    /**
     * Abstract method that runs the actual test.
     * 
     * @param size Context dependent size parameter, such as the number of statements to create
     */
    public void runTest( int size ) 
        throws Exception
    {
        Resource r = m_model.getResource( START );
        
        for (int i = 0;  i < size; i++) {
            r = (Resource) r.getProperty( m_p ).getObject();
        }
    }
    

    /**
     * Answer the human readable description of the test, that will appear on the generated html
     * @return The description of the test
     */
    public String getDescription() {
        return "Walk a chain of 'size' linked statements from beginning to end";
    }
    

    /**
     * Entry point
     */
    public static void main( String[] args ) {
        new WalkTest_Jena1().go( args );
    }


} //end of class


