/********************************************************************
 * File:         PerformanceTest.java
 * RCS:          $Header: /cvsroot/jena//jena-perf/src/com/hp/hpl/jena/test/performance/WritePerfTest_Jena1.java,v 1.1 2003/01/23 16:25:19 ian_dickinson Exp $
 * Author:       Dave Reynolds, HPLabs, Bristol
 * Created:      5/12/02
 * Modified:     $Date: 2003/01/23 16:25:19 $
 * Package:      eperson
 * Status:       Experimental (Do Not Distribute)
 *
 * (c) Copyright 2002, Hewlett-Packard Company, all rights reserved.
 *********************************************************************/

// Package
package com.hp.hpl.jena.test.performance;

// Imports

import com.hp.hpl.mesa.rdf.jena.model.*;
import com.hp.hpl.mesa.rdf.jena.mem.*;
import com.hp.hpl.mesa.rdf.jena.vocabulary.*;

import java.io.*;


/**
* Performance test: walk a graph of connected statements from end to end
*
* @author <a href="mailto:Ian.Dickinson@hp.com">Ian Dickinson</a>
* @version $Revision: 1.1 $ on $Date: 2003/01/23 16:25:19 $
*/

public class WritePerfTest_Jena1
    extends AbstractPerfTest
{

    // Variables

    /** dummy namespace */
    public static final String NAMESPACE = "urn:x-hp-test:performance/";
    
    /** some arbitrary class */
    public static final String A_CLASS = "urn:x-hp-test:performance/A";

    /** The model to traverse */
    protected Model m_model = null;
    
    /**
     * Create a test model
     * @param size the number of statements to write out
     */
    public void setupTest( int size )  
        throws Exception 
    {
        m_model = new ModelMem();

        // Create  the properties
        Property p = m_model.createProperty( NAMESPACE, "p" );
        Resource cls = m_model.createResource( A_CLASS );
        
        // Create the statements
        for ( int i = 0;  i < size;  i++) {
            Resource r = m_model.createResource();
            r.addProperty( p, i );
            r.addProperty( RDF.type, cls );
        }
    }

    /**
     * Abstract method that runs the actual test.
     * 
     * @param size Context dependent size parameter, such as the number of statements to create
     */
    public void runTest( int size ) 
        throws Exception
    {
        File f = new File( "testwrite.rdf" );
        
        Writer out = new FileWriter(f);
        
        m_model.write( out, "RDF/XML" );
        
        out.close();
        f.delete();
    }
    

    /**
     * Answer the human readable description of the test, that will appear on the generated html
     * @return The description of the test
     */
    public String getDescription() {
        return "Write a model containing 'size' subjects - each with two properties - in RDF/XML";
    }
    

    /**
     * Entry point
     */
    public static void main( String[] args ) {
        new WritePerfTest_Jena1().go( args );
    }


} //end of class


